<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>

<head>
<meta http-equiv="Content-Language" content="ru-ru" />
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>pytils demo</title>
<style media="screen" type="text/css">
@import "/static/css/style.css";
</style>
</head>

<body>
<div id="header"></div>
<div id="main_content">
<h1><a href="/">pytils demo</a></h1>
{% block content %}
<p>Для того, чтобы воспользоваться pytils в Django, нужно:
<ol>
<li>Установить pytils (как это сделать написано в INSTALL, в архиве с pytils)</li>
<li>Добавить 'pytils' в INSTALLED_APPS</li>
<li>В шаблоне загрузить соответствующий компонент pytils (подробности см. в 
примерах к компонентам)</li>
<li>Вставить в нужном месте искомый тег/фильтр.</li>
</ol>
</p>
<p>
Компоненты pytils, доступные для загрузки:
<ul>
<!-- syntax of url tag has been changed in Django 1.5, so there is no way to prepare
example with url tag which will work on Django 1.3, 1.4, 1.5. Therefore, we'll use
hardcoded urls for this small demo -->
<li><a href="/dt/">pytils_dt</a> - работа с датами</li>
<li><a href="/numeral/">pytils_numeral</a> - работа с числами</li>
<li><a href="/translit/">pytils_translit</a> - простая транслитерация</li>
</ul>
</p>
<p><strong>Замечание:</strong> 
В зависимости от обстановки pytils по разному реагирует на ошибки при 
обработке тега/фильтра:
<ul>
<li>Если в режиме отладки (в settings указано <code>DEBUG = True</code>), то подставляется 
"unknown: краткое описание ошибки"</li>
<li>Если не в режиме отладки, то вместо значений подставляется пустая 
строка</li>
<li>Если не в режиме отладки, но в settings указано 
<code>PYTILS_SHOW_VALUES_ON_ERROR = True</code>, то вместо значений 
подставляются переданные параметры. Подробности см. в описании 
тегов/фильтров.</li>
</ul>
</p>

<p>Протестировано с</p>
<ul>
<li>Python 2.7 Django 1.3</li>
<li>Python 2.7 Django 1.4</li>
<li>Python 2.7 Django 1.5</li>
<li>Python 2.7 Django 1.6</li>
<li>Python 3.3 Django 1.5</li>
<li>Python 3.3 Django 1.6</li>
</ul>
<p>Данный пример работает с Django {{ django_version }} на Python {{ python_version }} с использованием pytils {{ pytils_version }}.</p>

{% endblock %}
</div>
<!-- End of main_content -->
<div id="footer">
<a href="http://github.com/j2a/pytils/">pytils</a> - 
простой обработчик русского текста. 
</div>
</body>

</html>
