/*
 * Quick mash-up of CSS for the TG quick start page with Django colors.
 */

html, body, th, td {
  color: black;
  background-color: #ddd;
  font: x-small "Lucida Grande", "Lucida Sans Unicode", geneva, verdana, sans-serif;
  margin: 0;
  padding: 0;
}

#header {
  height: 80px;
  width: 777px;
  background: green URL('../images/header_inner.png') no-repeat;
  border-left: 1px solid #aaa;
  border-right: 1px solid #aaa;
  margin: 0 auto 0 auto;
}

a.link, a, a.active {
  color: #ab5603;
}

a:hover {
  background-color: #e0ffb8;
  color: #234f32;
}


#main_content {
  color: black;
  font-size: 127%;
  background-color: white;
  width: 757px;
  margin: 0 auto 0 auto;
  border-left: 1px solid #aaa;
  border-right: 1px solid #aaa;
  padding: 10px;
}


h1,h2,h3,h4,h5,h6,#getting_started_steps {
  font-family: "Century Schoolbook L", Georgia, serif;
  font-weight: bold;
}

h2 {
  font-size:150%
}

#footer {
  border: 1px solid #aaa;
  border-top: 0px none;
  color: #999;
  background-color: white;
  padding: 10px;
  font-size: 90%;
  text-align: center;
  width: 757px;
  margin: 0 auto 1em auto;
}

.code {
  font-family: monospace;
}

pre {
  background-color: #e0ffb8; 
  border: 1px solid #94da3a; 
  border-width: 1px 0;
}

span.code {
  font-weight: bold;
  background: #eee;
}

